==> foundation-ui-components-1.2.0.tgz: package/src/common/progress/NsProgress.spec.tsx <==
import { render, screen } from '@testing-library/react';
import React from 'react';
import Progress from './NsProgress';

describe(' NsProgress Component', () => {
    test('should render Progress bar', () => {
        render(<Progress color="primary" value={10}></Progress>);

        const pbar = screen.getByRole('progressbar');

        expect(pbar).toBeInTheDocument();
    });

    it('matches the height of the progress bar to the width of the container', () => {
        // Define the props
        const value = 50;

        // Render the StyledProgress component with the value prop
        const { container } = render(<Progress color="primary" value={value} />);

        // Get the progress bar element
        const progressBar = container.querySelector('.MuiLinearProgress-bar');

        // Check if the progress bar element exists
        if (progressBar) {
            // Retrieve the computed width of the container element
            const containerWidth = container.clientWidth;

            // Retrieve the computed styles of the progress bar
            const progressBarStyle = getComputedStyle(progressBar);
            const progressBarHeight = parseFloat(progressBarStyle.height);
            const progressBarPadding =
                parseFloat(progressBarStyle.paddingTop) + parseFloat(progressBarStyle.paddingBottom);
            const progressBarBorder =
                parseFloat(progressBarStyle.borderTopWidth) + parseFloat(progressBarStyle.borderBottomWidth);

            // Calculate the expected height of the progress bar
            const expectedHeight = containerWidth - progressBarPadding - progressBarBorder;

            // Assert that the height of the progress bar matches the width of the container
            expect(progressBarHeight).toBe(expectedHeight);
        } else {
            // Handle the case where the progress bar element is not found
            throw new Error('Progress bar element not found');
        }
    });
});

==> foundation-ui-components-1.30.1.tgz: package/src/common/progress/NsProgress.spec.tsx <==
import { render, screen } from '@testing-library/react';
import React from 'react';
import Progress from './NsProgress';

describe(' NsProgress Component', () => {
    test('should render Progress bar', () => {
        render(<Progress barColor="primary" value={10}></Progress>);

        const pbar = screen.getByRole('progressbar');

        expect(pbar).toBeInTheDocument();
    });

    it('matches the height of the progress bar to the width of the container', () => {
        // Define the props
        const value = 50;

        // Render the StyledProgress component with the value prop
        const { container } = render(<Progress barColor="primary" value={value} />);

        // Get the progress bar element
        const progressBar = container.querySelector('.MuiLinearProgress-bar');

        // Check if the progress bar element exists
        if (progressBar) {
            // Retrieve the computed width of the container element
            const containerWidth = container.clientWidth;

            // Retrieve the computed styles of the progress bar
            const progressBarStyle = getComputedStyle(progressBar);
            const progressBarHeight = parseFloat(progressBarStyle.height);
            const progressBarPadding =
                parseFloat(progressBarStyle.paddingTop) + parseFloat(progressBarStyle.paddingBottom);
            const progressBarBorder =
                parseFloat(progressBarStyle.borderTopWidth) + parseFloat(progressBarStyle.borderBottomWidth);

            // Calculate the expected height of the progress bar
            const expectedHeight = containerWidth - progressBarPadding - progressBarBorder;

            // Assert that the height of the progress bar matches the width of the container
            expect(progressBarHeight).toBe(expectedHeight);
        } else {
            // Handle the case where the progress bar element is not found
            throw new Error('Progress bar element not found');
        }
    });
});
